@@ -86,7 +86,7 @@
 #define KDESU_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KDESU_NO_DEPRECATED
-#  define KDESU_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54300
+#  define KDESU_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54c00
 #endif
 #ifdef KDESU_NO_DEPRECATED_WARNINGS
 #  define KDESU_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KDESU_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KDESU_DEPRECATED_WARNINGS_SINCE KDESU_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KDESU_DEPRECATED_WARNINGS_SINCE 0x54300
+#    define KDESU_DEPRECATED_WARNINGS_SINCE 0x54c00
 #  endif
 #endif
 
@@ -117,5 +117,6 @@
 #endif
 #define KDESU_DEPRECATED_VERSION_5(minor, text)      KDESU_DEPRECATED_VERSION_5_##minor(text)
 #define KDESU_DEPRECATED_VERSION(major, minor, text) KDESU_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
+#define KDESU_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KDESU_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
 
 #endif /* KDESU_EXPORT_H */
